@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Optional
 
 from pydantic import BaseModel
 
@@ -11,6 +11,12 @@ class Metric(BaseModel):
     code: str
     aggregation_type: str
 
+class Group(BaseModel):
+    lago_id: str
+    key: Optional[str]
+    value: str
+    units: str
+    amount_cents: int
 
 class ChargeObject(BaseModel):
     lago_id: str
@@ -23,16 +29,15 @@ class ChargeUsage(BaseModel):
     amount_currency: str
     charge: ChargeObject
     billable_metric: Metric
+    groups: List[Group]
 
 
 class CustomerUsageResponse(BaseResponseModel):
     from_datetime: str
     to_datetime: str
     issuing_date: str
+    currency: str
     amount_cents: int
-    amount_currency: str
     total_amount_cents: int
-    total_amount_currency: str
-    vat_amount_cents: int
-    vat_amount_currency: str
+    taxes_amount_cents: int
     charges_usage: List[ChargeUsage]
