@@ -1,5 +1,8 @@
-from pydantic import BaseModel, Field
-from typing import Optional, List
+from typing import List, Optional
+
+from pydantic import BaseModel
+
+from ..base_model import BaseResponseModel
 
 
 class Subscription(BaseModel):
@@ -9,9 +12,10 @@ class Subscription(BaseModel):
     external_id: Optional[str]
     subscription_date: Optional[str]
     billing_time: Optional[str]
+    ending_at: Optional[str]
 
 
-class SubscriptionResponse(BaseModel):
+class SubscriptionResponse(BaseResponseModel):
     lago_id: str
     lago_customer_id: Optional[str]
     external_customer_id: Optional[str]
@@ -24,10 +28,12 @@ class SubscriptionResponse(BaseModel):
     external_id: Optional[str]
     billing_time: Optional[str]
     terminated_at: Optional[str]
+    ending_at: Optional[str]
     subscription_date: Optional[str]
     previous_plan_code: Optional[str]
     next_plan_code: Optional[str]
     downgrade_plan_date: Optional[str]
 
-class SubscriptionsResponse(BaseModel):
+
+class SubscriptionsResponse(BaseResponseModel):
     __root__: List[SubscriptionResponse]
